pub struct Flow {Show 16 fields
pub pk: Uuid,
pub policybindingmodel_ptr_id: Uuid,
pub name: String,
pub slug: String,
pub title: String,
pub designation: FlowDesignationEnum,
pub background: String,
pub stages: Vec<Uuid>,
pub policies: Vec<Uuid>,
pub cache_count: i32,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub compatibility_mode: Option<bool>,
pub export_url: String,
pub layout: Option<FlowLayoutEnum>,
pub denied_action: Option<DeniedActionEnum>,
pub authentication: Option<AuthenticationEnum>,
}Expand description
Flow : Flow Serializer
Fields
pk: Uuidpolicybindingmodel_ptr_id: Uuidname: Stringslug: StringVisible in the URL.
title: StringShown as the Title in Flow pages.
designation: FlowDesignationEnumDecides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik. * authentication - Authentication * authorization - Authorization * invalidation - Invalidation * enrollment - Enrollment * unenrollment - Unrenollment * recovery - Recovery * stage_configuration - Stage Configuration
background: StringGet the URL to the background image. If the name is /static or starts with http it is returned as-is
stages: Vec<Uuid>policies: Vec<Uuid>cache_count: i32Get count of cached flows
policy_engine_mode: Option<PolicyEngineMode>compatibility_mode: Option<bool>Enable compatibility mode, increases compatibility with password managers on mobile devices.
export_url: StringGet export URL for flow
layout: Option<FlowLayoutEnum>denied_action: Option<DeniedActionEnum>Configure what should happen when a flow denies access to a user. * message_continue - Message Continue * message - Message * continue - Continue
authentication: Option<AuthenticationEnum>Required level of authentication and authorization to access a flow. * none - None * require_authenticated - Require Authenticated * require_unauthenticated - Require Unauthenticated * require_superuser - Require Superuser * require_outpost - Require Outpost