pub struct FlowRequest {
pub name: String,
pub slug: String,
pub title: String,
pub designation: FlowDesignationEnum,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub compatibility_mode: Option<bool>,
pub layout: Option<FlowLayoutEnum>,
pub denied_action: Option<DeniedActionEnum>,
pub authentication: Option<AuthenticationEnum>,
}Expand description
FlowRequest : Flow Serializer
Fields
name: Stringslug: StringVisible in the URL.
title: StringShown as the Title in Flow pages.
designation: FlowDesignationEnumDecides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik. * authentication - Authentication * authorization - Authorization * invalidation - Invalidation * enrollment - Enrollment * unenrollment - Unrenollment * recovery - Recovery * stage_configuration - Stage Configuration
policy_engine_mode: Option<PolicyEngineMode>compatibility_mode: Option<bool>Enable compatibility mode, increases compatibility with password managers on mobile devices.
layout: Option<FlowLayoutEnum>denied_action: Option<DeniedActionEnum>Configure what should happen when a flow denies access to a user. * message_continue - Message Continue * message - Message * continue - Continue
authentication: Option<AuthenticationEnum>Required level of authentication and authorization to access a flow. * none - None * require_authenticated - Require Authenticated * require_unauthenticated - Require Unauthenticated * require_superuser - Require Superuser * require_outpost - Require Outpost
Implementations
Sourceimpl FlowRequest
impl FlowRequest
Sourcepub fn new(
name: String,
slug: String,
title: String,
designation: FlowDesignationEnum,
) -> FlowRequest
pub fn new( name: String, slug: String, title: String, designation: FlowDesignationEnum, ) -> FlowRequest
Flow Serializer