pub struct LdapSourceRequest {Show 28 fields
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
pub server_uri: String,
pub peer_certificate: Option<Option<Uuid>>,
pub client_certificate: Option<Option<Uuid>>,
pub bind_cn: Option<String>,
pub bind_password: Option<String>,
pub start_tls: Option<bool>,
pub sni: Option<bool>,
pub base_dn: String,
pub additional_user_dn: Option<String>,
pub additional_group_dn: Option<String>,
pub user_object_filter: Option<String>,
pub group_object_filter: Option<String>,
pub group_membership_field: Option<String>,
pub object_uniqueness_field: Option<String>,
pub sync_users: Option<bool>,
pub sync_users_password: Option<bool>,
pub sync_groups: Option<bool>,
pub sync_parent_group: Option<Option<Uuid>>,
pub property_mappings: Option<Vec<Uuid>>,
pub property_mappings_group: Option<Vec<Uuid>>,
}Expand description
LdapSourceRequest : LDAP Source Serializer
Fields
name: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled. * identifier - Use the source-specific identifier * email_link - Link to a user with identical email address. Can have security implications when a source doesn’t validate email addresses. * email_deny - Use the user’s email address, but deny enrollment when the email address already exists. * username_link - Link to a user with identical username. Can have security implications when a username is used with another source. * username_deny - Use the user’s username, but deny enrollment when the username already exists.
user_path_template: Option<String>server_uri: Stringpeer_certificate: Option<Option<Uuid>>Optionally verify the LDAP Server’s Certificate against the CA Chain in this keypair.
client_certificate: Option<Option<Uuid>>Client certificate to authenticate against the LDAP Server’s Certificate.
bind_cn: Option<String>bind_password: Option<String>start_tls: Option<bool>sni: Option<bool>base_dn: Stringadditional_user_dn: Option<String>Prepended to Base DN for User-queries.
additional_group_dn: Option<String>Prepended to Base DN for Group-queries.
user_object_filter: Option<String>Consider Objects matching this filter to be Users.
group_object_filter: Option<String>Consider Objects matching this filter to be Groups.
group_membership_field: Option<String>Field which contains members of a group.
object_uniqueness_field: Option<String>Field which contains a unique Identifier.
sync_users: Option<bool>sync_users_password: Option<bool>When a user changes their password, sync it back to LDAP. This can only be enabled on a single LDAP source.
sync_groups: Option<bool>sync_parent_group: Option<Option<Uuid>>property_mappings: Option<Vec<Uuid>>property_mappings_group: Option<Vec<Uuid>>Property mappings used for group creation/updating.
Implementations