pub struct OAuthSourceRequest {Show 19 fields
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
pub provider_type: ProviderTypeEnum,
pub request_token_url: Option<Option<String>>,
pub authorization_url: Option<Option<String>>,
pub access_token_url: Option<Option<String>>,
pub profile_url: Option<Option<String>>,
pub consumer_key: String,
pub consumer_secret: String,
pub additional_scopes: Option<String>,
pub oidc_well_known_url: Option<String>,
pub oidc_jwks_url: Option<String>,
pub oidc_jwks: Option<Option<Value>>,
}Expand description
OAuthSourceRequest : OAuth Source Serializer
Fields
name: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled. * identifier - Use the source-specific identifier * email_link - Link to a user with identical email address. Can have security implications when a source doesn’t validate email addresses. * email_deny - Use the user’s email address, but deny enrollment when the email address already exists. * username_link - Link to a user with identical username. Can have security implications when a username is used with another source. * username_deny - Use the user’s username, but deny enrollment when the username already exists.
user_path_template: Option<String>provider_type: ProviderTypeEnumrequest_token_url: Option<Option<String>>URL used to request the initial token. This URL is only required for OAuth 1.
URL the user is redirect to to conest the flow.
access_token_url: Option<Option<String>>URL used by authentik to retrieve tokens.
profile_url: Option<Option<String>>URL used by authentik to get user information.
consumer_key: Stringconsumer_secret: Stringadditional_scopes: Option<String>oidc_well_known_url: Option<String>oidc_jwks_url: Option<String>oidc_jwks: Option<Option<Value>>Implementations
Sourceimpl OAuthSourceRequest
impl OAuthSourceRequest
Sourcepub fn new(
name: String,
slug: String,
provider_type: ProviderTypeEnum,
consumer_key: String,
consumer_secret: String,
) -> OAuthSourceRequest
pub fn new( name: String, slug: String, provider_type: ProviderTypeEnum, consumer_key: String, consumer_secret: String, ) -> OAuthSourceRequest
OAuth Source Serializer