pub struct SamlSourceRequest {Show 20 fields
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
pub pre_authentication_flow: Uuid,
pub issuer: Option<String>,
pub sso_url: String,
pub slo_url: Option<Option<String>>,
pub allow_idp_initiated: Option<bool>,
pub name_id_policy: Option<NameIdPolicyEnum>,
pub binding_type: Option<BindingTypeEnum>,
pub verification_kp: Option<Option<Uuid>>,
pub signing_kp: Option<Option<Uuid>>,
pub digest_algorithm: Option<DigestAlgorithmEnum>,
pub signature_algorithm: Option<SignatureAlgorithmEnum>,
pub temporary_user_delete_after: Option<String>,
}Expand description
SamlSourceRequest : SAMLSource Serializer
Fields
name: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled. * identifier - Use the source-specific identifier * email_link - Link to a user with identical email address. Can have security implications when a source doesn’t validate email addresses. * email_deny - Use the user’s email address, but deny enrollment when the email address already exists. * username_link - Link to a user with identical username. Can have security implications when a username is used with another source. * username_deny - Use the user’s username, but deny enrollment when the username already exists.
user_path_template: Option<String>pre_authentication_flow: UuidFlow used before authentication.
issuer: Option<String>Also known as Entity ID. Defaults the Metadata URL.
sso_url: StringURL that the initial Login request is sent to.
slo_url: Option<Option<String>>Optional URL if your IDP supports Single-Logout.
allow_idp_initiated: Option<bool>Allows authentication flows initiated by the IdP. This can be a security risk, as no validation of the request ID is done.
name_id_policy: Option<NameIdPolicyEnum>NameID Policy sent to the IdP. Can be unset, in which case no Policy is sent. * urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress - Email * urn:oasis:names:tc:SAML:2.0:nameid-format:persistent - Persistent * urn:oasis:names:tc:SAML:2.0:nameid-format:X509SubjectName - X509 * urn:oasis:names:tc:SAML:2.0:nameid-format:WindowsDomainQualifiedName - Windows * urn:oasis:names:tc:SAML:2.0:nameid-format:transient - Transient
binding_type: Option<BindingTypeEnum>verification_kp: Option<Option<Uuid>>When selected, incoming assertion’s Signatures will be validated against this certificate. To allow unsigned Requests, leave on default.
signing_kp: Option<Option<Uuid>>Keypair used to sign outgoing Responses going to the Identity Provider.
digest_algorithm: Option<DigestAlgorithmEnum>signature_algorithm: Option<SignatureAlgorithmEnum>temporary_user_delete_after: Option<String>Time offset when temporary users should be deleted. This only applies if your IDP uses the NameID Format ‘transient’, and the user doesn’t log out manually. (Format: hours=1;minutes=2;seconds=3).
Implementations