pub struct SourceRequest {
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
}Expand description
SourceRequest : Source Serializer
Fields
name: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled. * identifier - Use the source-specific identifier * email_link - Link to a user with identical email address. Can have security implications when a source doesn’t validate email addresses. * email_deny - Use the user’s email address, but deny enrollment when the email address already exists. * username_link - Link to a user with identical username. Can have security implications when a username is used with another source. * username_deny - Use the user’s username, but deny enrollment when the username already exists.
user_path_template: Option<String>Implementations
Sourceimpl SourceRequest
impl SourceRequest
Sourcepub fn new(name: String, slug: String) -> SourceRequest
pub fn new(name: String, slug: String) -> SourceRequest
Source Serializer